==> spatstat_1.1-3.tar.gz: spatstat/data/ganglia.R <==
"ganglia" <-
structure(list(window = structure(list(type = "rectangle", xrange = c(0, 
1), yrange = c(0, 0.7533)), .Names = c("type", "xrange", "yrange"
), class = "owin"), n = 135, x = c(0.013, 0.032, 0.065, 0.084, 
0.078, 0.026, 0.117, 0.13, 0.11, 0.182, 0.182, 0.208, 0.214, 
0.214, 0.234, 0.26, 0.299, 0.331, 0.344, 0.338, 0.325, 0.312, 
0.37, 0.39, 0.383, 0.429, 0.468, 0.442, 0.442, 0.448, 0.442, 
0.558, 0.571, 0.545, 0.558, 0.578, 0.565, 0.552, 0.649, 0.636, 
0.636, 0.688, 0.682, 0.688, 0.734, 0.779, 0.753, 0.766, 0.779, 
0.786, 0.831, 0.844, 0.831, 0.87, 0.896, 0.922, 0.935, 0.948, 
0.961, 0.974, 0.961, 0.974, 0.994, 0.747, 0.857, 0.084, 0.026, 
0.065, 0.104, 0.104, 0.039, 0.071, 0.136, 0.136, 0.175, 0.195, 
0.195, 0.188, 0.182, 0.214, 0.299, 0.266, 0.286, 0.266, 0.318, 
0.338, 0.383, 0.396, 0.409, 0.396, 0.461, 0.468, 0.455, 0.481, 
0.494, 0.506, 0.416, 0.61, 0.591, 0.571, 0.532, 0.578, 0.545, 
0.571, 0.584, 0.675, 0.695, 0.747, 0.688, 0.669, 0.662, 0.675, 
0.734, 0.701, 0.727, 0.773, 0.779, 0.792, 0.857, 0.818, 0.903, 
0.89, 0.87, 0.851, 0.831, 0.857, 0.818, 0.857, 0.909, 0.961, 
0.981, 0.981, 0.935, 0.948, 0.929), y = c(0.013, 0.149, 0.273, 
0.409, 0.545, 0.675, 0.714, 0.156, 0.026, 0.286, 0.506, 0.636, 
0.396, 0.136, 0.039, 0.208, 0.545, 0.649, 0.377, 0.299, 0.117, 
0.013, 0.474, 0.13, 0.201, 0.052, 0.156, 0.273, 0.39, 0.584, 
0.688, 0.052, 0.13, 0.195, 0.273, 0.442, 0.63, 0.727, 0.195, 
0.364, 0.545, 0.104, 0.273, 0.701, 0.442, 0.312, 0.188, 0.091, 
0.656, 0.747, 0.227, 0.078, 0.403, 0.649, 0.169, 0.299, 0.065, 
0.013, 0.169, 0.377, 0.481, 0.623, 0.708, 0.539, 0.519, 0.013, 
0.104, 0.188, 0.299, 0.416, 0.487, 0.708, 0.11, 0.61, 0.701, 
0.532, 0.442, 0.331, 0.208, 0.052, 0.143, 0.26, 0.377, 0.623, 
0.519, 0.045, 0.299, 0.429, 0.591, 0.727, 0.662, 0.519, 0.338, 
0.013, 0.117, 0.468, 0.221, 0.013, 0.084, 0.208, 0.24, 0.305, 
0.403, 0.545, 0.675, 0.006, 0.078, 0.156, 0.195, 0.26, 0.39, 
0.539, 0.623, 0.721, 0.448, 0.383, 0.26, 0.026, 0.039, 0.117, 
0.117, 0.188, 0.26, 0.325, 0.377, 0.481, 0.565, 0.688, 0.74, 
0.039, 0.13, 0.247, 0.344, 0.461, 0.597), marks = structure(c(2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1), .Label = c("0", "1"), class = "factor")), .Names = c("window", 
"n", "x", "y", "marks"), class = "ppp")

==> spatstat_1.3-1.tar.gz: spatstat/data/ganglia.R <==
"ganglia" <-
structure(list(window = structure(list(type = "rectangle", xrange = c(0, 
1), yrange = c(0, 0.7533)), .Names = c("type", "xrange", "yrange"
), class = "owin"), n = 135, x = c(0.013, 0.032, 0.065, 0.084, 
0.078, 0.026, 0.117, 0.13, 0.11, 0.182, 0.182, 0.208, 0.214, 
0.214, 0.234, 0.26, 0.299, 0.331, 0.344, 0.338, 0.325, 0.312, 
0.37, 0.39, 0.383, 0.429, 0.468, 0.442, 0.442, 0.448, 0.442, 
0.558, 0.571, 0.545, 0.558, 0.578, 0.565, 0.552, 0.649, 0.636, 
0.636, 0.688, 0.682, 0.688, 0.734, 0.779, 0.753, 0.766, 0.779, 
0.786, 0.831, 0.844, 0.831, 0.87, 0.896, 0.922, 0.935, 0.948, 
0.961, 0.974, 0.961, 0.974, 0.994, 0.747, 0.857, 0.084, 0.026, 
0.065, 0.104, 0.104, 0.039, 0.071, 0.136, 0.136, 0.175, 0.195, 
0.195, 0.188, 0.182, 0.214, 0.299, 0.266, 0.286, 0.266, 0.318, 
0.338, 0.383, 0.396, 0.409, 0.396, 0.461, 0.468, 0.455, 0.481, 
0.494, 0.506, 0.416, 0.61, 0.591, 0.571, 0.532, 0.578, 0.545, 
0.571, 0.584, 0.675, 0.695, 0.747, 0.688, 0.669, 0.662, 0.675, 
0.734, 0.701, 0.727, 0.773, 0.779, 0.792, 0.857, 0.818, 0.903, 
0.89, 0.87, 0.851, 0.831, 0.857, 0.818, 0.857, 0.909, 0.961, 
0.981, 0.981, 0.935, 0.948, 0.929), y = c(0.013, 0.149, 0.273, 
0.409, 0.545, 0.675, 0.714, 0.156, 0.026, 0.286, 0.506, 0.636, 
0.396, 0.136, 0.039, 0.208, 0.545, 0.649, 0.377, 0.299, 0.117, 
0.013, 0.474, 0.13, 0.201, 0.052, 0.156, 0.273, 0.39, 0.584, 
0.688, 0.052, 0.13, 0.195, 0.273, 0.442, 0.63, 0.727, 0.195, 
0.364, 0.545, 0.104, 0.273, 0.701, 0.442, 0.312, 0.188, 0.091, 
0.656, 0.747, 0.227, 0.078, 0.403, 0.649, 0.169, 0.299, 0.065, 
0.013, 0.169, 0.377, 0.481, 0.623, 0.708, 0.539, 0.519, 0.013, 
0.104, 0.188, 0.299, 0.416, 0.487, 0.708, 0.11, 0.61, 0.701, 
0.532, 0.442, 0.331, 0.208, 0.052, 0.143, 0.26, 0.377, 0.623, 
0.519, 0.045, 0.299, 0.429, 0.591, 0.727, 0.662, 0.519, 0.338, 
0.013, 0.117, 0.468, 0.221, 0.013, 0.084, 0.208, 0.24, 0.305, 
0.403, 0.545, 0.675, 0.006, 0.078, 0.156, 0.195, 0.26, 0.39, 
0.539, 0.623, 0.721, 0.448, 0.383, 0.26, 0.026, 0.039, 0.117, 
0.117, 0.188, 0.26, 0.325, 0.377, 0.481, 0.565, 0.688, 0.74, 
0.039, 0.13, 0.247, 0.344, 0.461, 0.597), marks = structure(c(2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1), .Label = c("off", "on"), class = "factor")), .Names = c("window", 
"n", "x", "y", "marks"), class = "ppp")
